<?php
namespace THM\DownloadExplorer\Controller;


/***************************************************************
 *
 *  Copyright notice
 *
 *  (c) 2014 Jan Haffner <info@jan-haffner.de>
 *           Rafael Kähm <Rafael@Kaehms.de>
 *           Samuel Mehrbrodt <samuel.mehrbrodt@mni.thm.de>
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use \TYPO3\CMS\Core\Utility\GeneralUtility;

/**
 * StandardController
 */
class StandardController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController {

	/**
	 * @var \THM\DownloadExplorer\Utility\Files
	 */
	protected $fileUtility;

	/** A list of IANA media types which are supported by this controller */
	protected $supportedMediaTypes = array('application/json', 'text/html');

	protected $viewFormatToObjectNameMap = array(
		'html' => 'TYPO3\Fluid\View\TemplateView',
		'json' => '\TYPO3\CMS\Extbase\Mvc\View\JsonView'
	);

	/**
	 * Initializes the controller before invoking an action method.
	 *
	 * Inializes Files Utility, Sets Settings for Files Utility and fixes #43504 from TYPO3 FileAdmin.
	 *
	 * @todo: if #43504 is fixed, add check TYPO3 CMS version before call hotFixFor43504().
	 *
	 * @return void
	 */
	public function initializeAction() {
		$this->hotFixFor43504();
		$this->fileUtility = GeneralUtility::makeInstance('THM\\DownloadExplorer\\Utility\\Files');
		$this->fileUtility->setSettings($this->settings);
	}

	/**
	 * Lists folder tree in frontend.
	 *
	 * @return void
	 */
	public function listAction() {
		$subFolderAndFiles = array();
		$this->fileUtility->readDirectoryRecursively($this->settings['rootFolder'], $subFolderAndFiles, TRUE, $this->settings['foldersDepth']);
		$this->view->assign('subfoldersAndFiles', $subFolderAndFiles);
	}

	/**
	 * This is the hotfix for #43504 from TYPO3 CMS
	 *
	 * @todo: remove all hotFixFor43504() and calls from hotFixFor43504 if bug is fixed.
	 *
	 * @return void
	 */
	private function hotFixFor43504() {
		$fileInfo = new \SplFileInfo($this->settings['rootFolder']);
		if ($fileInfo->isFile() || ($fileInfo->getFilename() == '_isBasefolder')) {
			$this->settings['rootFolder'] = $fileInfo->getPath();
		}
	}
}